# OZGCloud Zufi-Manager

## Fachlichkeit
- Aus dem OZG-Gesetz folgend, gibt es für Leistungen Zuständigkeiten, d.h. Orte/Personen/Behörden... an denen Leistungen erbracht werden. 
- "Zuständigkeitsfinder" ist ein Verzeichnis von Verwaltungsleistungen und katalogisiert z.B. Erbringer, Ort, OrganisationseinheitenID, ...
- Beispiele: [Sachsen](https://amt24.sachsen.de/zufi), [Schleswig-Holstein](https://zufish.schleswig-holstein.de/)
- Es gibt ein Zentral-System namens [PVOG (Portalverbund Online Gateway)](https://anbindung.pvog.cloud-bdc.dataport.de/)
  - Hier werden Daten der Bundesland-Zufis gesammelt ("Sammlerdienst")
  - Möglichkeit zur zentralen Abfrage ("Bereitstellungsdienst" und "Suchdienst")

## Definitionen und Abkürzungen
* ZuFi 
  * Zuständigkeitsfinder, ein Verzeichnis von Verwaltungsleistungen
* PVOG
  * Portalverbund Online-Gateway, Datenquelle
* OrganisationsEinheit
  * technische Bezeichnung im XZufi-Standard für eine Behörde
  * Teil der PVOG-Daten
  * wird durch eine OID identifiziert
* OID
  * kurz für OrganisationsEinheitID
  * identifiziert eine OrganisationsEinheit
  * wird von einem Herausgeber erstellt, der hier aber nicht genannt ist
* XZufi-OID
  * Enthält den numerischen Identifier der Behörde und den numerischen Identifier des Herausgebers (z.B. TSA Public Service GmbH für das Land Schleswig-Holstein) 
  * ist nur in der Kombination eindeutig
  * Die Unterscheidung ist erforderlich, da es Zufi-Deployments geben könnte, die neben Behörden eines Bundeslandes andere Behörden (z.B. Bundesebene) mit einem anderen Herausgeber enthalten. Nur über die OID kann eine Behörde nicht exakt bestimmt werden. 
* Fachstelle
  * Bezeichnung für eine Einheit, die fachliche Aufgaben übernimmt, aber beliebiger Natur sein kann
  * Beispiele: Vereine, Schulen, Firmen, ...
  * Nicht in den PVOG Daten enthalten  

## Technische Details PVOG-Bereitstellungsdienst
- wird über das Internet aufgerufen
- stellt eine REST API bereit
- benötigt ein OAUTH2-Token bei Verwendung - Man erhält ein Token, in dem man den dortigen Keycloak mit unserem API-Key aufruft
- Das Datenformat heißt [XZufi](https://www.xrepository.de/details/urn:xoev-de:fim:standard:xzufi) (XOEV Standard) und wird in XML oder JSON zurückgeliefert
- Mehr Informationen unter [Dokumentation API Bereitstellungsdienst](https://anbindung.pvog.cloud-bdc.dataport.de/docs/bed/bed-doku)

# Software-Komponente zufi

## Aufbau
- Modul "zufi-manager" (Source: zufi-manager-pvog)
  - ist eine Job-Anwendung
  - Abruf der PVOG Daten über Verwaltungsleistungen
  - Die Daten werden in einer MongoDB-Datenbank gespeichert
  - Ausführung: Als regelmäßiger Job im Kubernetes-Cluster (aller 15min laut Helm-Chart)
- Modul "zufi-server" (Source: zufi-manager-server)
  - ist ein dauerhaft ausgeführter Microservice 
  - steht für verschiedene Anwendungszwecke zur Verfügung
  - wird in einem zentralen Namespace deployed (analog Keycloak)

## Anwendungsfälle
* Suche nach Organisationseinheiten
  * Eingabe von Suchbegriffen
  * Rückgabe von Organisationseinheit-Objekten
* Registrierung vorgang-manager auf XZufi-OIDs
  * vorgang-manager einer Kommune verarbeiten konkrete XZufi-OIDs
  * Beim Start dieser Anwendung kann eine Registrierung am Zufi erfolgen
* Abruf vorgang-manager 
  * Sofern ein vorgang-manager registriert ist, kann dessen Adresse unter Angabe einer OID erfragt werden
    * Hinweis: Die ausschließliche Verwendung der OID ist veraltet. Es wird empfohlen, die XZufi-OID zu verwenden.  
* Registrierung Fachstelle
  * betrifft externe Fachstellen (also keine Behörden/Organisationseinheiten aus den PVOG-Daten) 
  * Fachstellen können sich in der OZGCloud registrieren, die Daten werden hier gespeichert 
* Suche nach Fachstelle
  * Eingabe von Suchbegriffen
  * Rückgabe von Fachstelle-Objekten

## Manuelle Tests
* Mit "OpenShift CLI" Kontakt zum Cluster aufnehmen: \
  `oc login [cluster]`
* Projekt auswählen \
  `oc project by-zufi-dev`
* Name des Server-Pods holen \
  `oc get pods`
* Port-Forwarding \
  `oc port-forward zufi-server-... 55555:9090`
* Mit [Postman](https://www.postman.com) eine grpc-Verbindung aufbauen zu `localhost:55555`
* API abrufen und Requests ausführen


## Konfiguration
This properties must be configured to run the application:

| Key                                  | Value                             | Default | Mandatory | Description                                                               |
|--------------------------------------|-----------------------------------|---------| --------- |---------------------------------------------------------------------------|
| spring.data.mongodb.uri              | mongodb://localhost:27017/zufi-db | none    | yes | The connection string or url to mongoDB                                   |
| spring.data.mongodb.database         | zufi-database                     | none    | no  | Database name, has to be set if not specified in uri                      |
| ozgcloud.pvog.oauth2.auth-server-url | https://sso.pvog.service          | none    | yes | Address of the PVOG SSO                                                   |
| ozgcloud.pvog.oauth2.realm           | realm                             | none    | yes | Namespace to manage SSO settings (Keycloak realm)                         |
| ozgcloud.pvog.oauth2.client-id       | ozgcloud                          | none    | yes | Id of the PVOG SSO client                                                 |
| ozgcloud.pvog.oauth2.client-secret   | secret                            | none    | yes | The secret of the PVOG SSO client                                         |
| ozgcloud.pvog.url                    | https://pvog.service              | none    | yes | The address of the PVOG service                                           |
| ozgcloud.pvog.endpoints.verwaltungsobjekte.path           | /v2/verwaltungsobjekte            | none    | yes | Path of the endpoint that delivers Verwaltungsdaten                       |
| ozgcloud.zufi.land.amtliche-regional-schluessel                 | 01%                               | none    | no | The ARS code used for requests |

# Architekturgrafik

![Architekturgrafik](assets/ozgcloud-pvog-anbindung.png "Darstellung der Interaktionen von OZGCloud mit dem PVOG System")
