/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import java.util.List;
import java.util.Optional;

import org.springframework.data.mongodb.core.query.TextCriteria;
import org.springframework.data.mongodb.repository.MongoRepository;
import org.springframework.data.mongodb.repository.Query;
import org.springframework.stereotype.Repository;

@Repository
interface OrganisationsEinheitRepository extends MongoRepository<OrganisationsEinheit, String> {

	Optional<OrganisationsEinheit> findFirstByXzufiIdId(String organisationsEinheitId);

	Optional<OrganisationsEinheit> findFirstByXzufiId(XzufiId xZufiId);

	void deleteByXzufiId(XzufiId xZufiId);

	List<OrganisationsEinheit> findAllByZustaendigkeitenGebietIdOrderByScoreDesc(String gebietId, TextCriteria textCriteria);

	default List<OrganisationsEinheit> findAllContainingInGebiet(String text, String gebietId) {
		return findAllByZustaendigkeitenGebietIdOrderByScoreDesc(gebietId, buildTextCriteria(text));
	}

	List<OrganisationsEinheit> findAllByOrderByScoreDesc(TextCriteria textCriteria);

	default List<OrganisationsEinheit> findAllContaining(String text) {
		return findAllByOrderByScoreDesc(buildTextCriteria(text));
	}

	default TextCriteria buildTextCriteria(String text) {
		return TextCriteria.forDefaultLanguage().matching(text);
	}

	@Query("{ 'xzufiId._id': ?0 }")
	List<OrganisationsEinheit> findByOrganisationsEinheitId(String organisationsEinheitId);
}


