/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.fachstelle;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.List;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Mock;
import org.mockito.Spy;
import org.springframework.data.mongodb.core.query.TextCriteria;

import com.thedeanda.lorem.LoremIpsum;

class FachstelleRepositoryTest {

	@Spy
	private FachstelleRepository repository;

	@Nested
	class TestFindAllContaining {

		private final String searchBy = LoremIpsum.getInstance().getWords(1);

		@Mock
		private TextCriteria textCriteria;

		@Test
		void shouldBuildTextCriteria() {
			callRepository();

			verify(repository).buildTextCriteria(searchBy);
		}

		@Test
		void shouldFindAllByOrderByScoreDesc() {
			doReturn(textCriteria).when(repository).buildTextCriteria(searchBy);

			callRepository();

			verify(repository).findAllByOrderByScoreDesc(textCriteria);
		}

		@Test
		void shouldReturnFoundFachstellen() {
			var expectedFachstellen = List.of(FachstelleTestFactory.create());
			doReturn(textCriteria).when(repository).buildTextCriteria(searchBy);
			doReturn(expectedFachstellen).when(repository).findAllByOrderByScoreDesc(textCriteria);

			var fachstellen = callRepository();

			assertThat(fachstellen).isEqualTo(expectedFachstellen);
		}

		private List<Fachstelle> callRepository() {
			return repository.findAllContaining(searchBy);
		}
	}

	@Nested
	class TestTextCriteria {

		private final String searchBy = LoremIpsum.getInstance().getWords(1);

		@Test
		void shouldReturnTextCriteria() {
			var expectedTextCriteria = TextCriteria.forDefaultLanguage().matching(searchBy);

			var resultTextCriteria = repository.buildTextCriteria(searchBy);

			assertThat(resultTextCriteria).usingRecursiveComparison().isEqualTo(expectedTextCriteria);
		}
	}
}
