/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import java.util.HashSet;
import java.util.Set;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

public class OrganisationsEinheitTestFactory {
	public static final String ID = UUID.randomUUID().toString();
	public static final XzufiId XZUFI_ID = XzufiIdTestFactory.create();
	public static final String NAME = LoremIpsum.getInstance().getName();
	public static final String SYNONYME = LoremIpsum.getInstance().getWords(5);
	public static final Anschrift ANSCHRIFT = AnschriftTestFactory.create();
	public static final Set<Zustaendigkeit> ZUSTAENDIGKEITEN = new HashSet<>(Set.of(ZustaendigkeitTestFactory.create()));
	public static final String VORGANG_MANAGER_ADDRESS = LoremIpsum.getInstance().getUrl();

	public static OrganisationsEinheit create() {
		return createBuilder().build();
	}

	public static OrganisationsEinheit.OrganisationsEinheitBuilder createBuilder() {
		return OrganisationsEinheit.builder()
				.id(ID)
				.xzufiId(XZUFI_ID)
				.name(NAME)
				.synonyme(SYNONYME)
				.anschrift(ANSCHRIFT)
				.zustaendigkeiten(ZUSTAENDIGKEITEN)
				.vorgangManagerAddress(VORGANG_MANAGER_ADDRESS);
	}
}
