/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import java.util.List;
import java.util.Optional;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.Named;

import de.ozgcloud.zufi.schema.AnschriftOrganisationseinheit;

@Mapper
interface AnschriftMapper {

	default Anschrift fromXzufiAnschriften(List<AnschriftOrganisationseinheit> anschriften) {
		return anschriften.stream()
				.findFirst()
				.map(this::fromXzufiAnschrift)
				.orElseGet(Anschrift.builder()::build);
	}

	@Mapping(target = "plz", source = "postleitzahl")
	@Mapping(target = "hausnummer", source = "hausnummer", qualifiedByName = "mapHausnummer")
	Anschrift fromXzufiAnschrift(AnschriftOrganisationseinheit anschrift);

	@Named("mapHausnummer")
	default String mapHausnummer(String hausnummer) {
		return Optional.ofNullable(hausnummer).map(String::strip).orElse(null);
	}
}
