/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import java.util.HashSet;
import java.util.List;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;

import de.ozgcloud.zufi.schema.Organisationseinheit;
import de.ozgcloud.zufi.schema.StringLocalized;

@Mapper(imports = HashSet.class, uses = { XzufiIdMapper.class, AnschriftMapper.class })
interface OrganisationsEinheitMapper {

	@Mapping(target = "vorgangManagerAddress", ignore = true)
	@Mapping(target = "id", ignore = true)
	@Mapping(target = "score", ignore = true)

	@Mapping(target = "xzufiId", source = "id")
	@Mapping(target = "synonyme", source = "synonym")
	@Mapping(target = "name", source = "name.first.name.first.value")
	@Mapping(target = "zustaendigkeiten", expression = "java(new HashSet<>())")
	OrganisationsEinheit fromXZufiOrganisationseinheit(Organisationseinheit xZufiOrga);

	default String mapSynonyme(List<StringLocalized> xZufiSynonymes) {
		return xZufiSynonymes.stream()
				.map(StringLocalized::getValue)
				.collect(Collectors.joining(StringUtils.SPACE));
	}

}
