/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import java.util.Objects;

import org.springframework.stereotype.Component;

import de.ozgcloud.common.logging.OzgCloudLogging;
import lombok.RequiredArgsConstructor;

@Component
@OzgCloudLogging
@RequiredArgsConstructor
class OrganisationsEinheitProcessor extends TransferOperationEntryProcessor {

	private final OrganisationsEinheitRepository repository;

	@Override
	void processWrite(TransferOperationEntry transferOperationEntry) {
		var transferredOrganisationsEinheit = transferOperationEntry.getOrganisationsEinheit();
		var updatedOrganisationsEinheit = repository
				.findFirstByXzufiId(transferredOrganisationsEinheit.getXzufiId())
				.map(persistedOrganisationsEinheit -> updateOrganisationsEinheit(persistedOrganisationsEinheit, transferredOrganisationsEinheit))
				.orElse(transferredOrganisationsEinheit);
		repository.save(updatedOrganisationsEinheit);
	}

	@Override
	void processDelete(TransferOperationEntry transferOperationEntry) {
		repository.deleteByXzufiId(transferOperationEntry.getOrganisationsEinheit().getXzufiId());
	}

	@Override
	boolean shouldProcess(TransferOperationEntry transferOperationEntry) {
		return Objects.nonNull(transferOperationEntry.getOrganisationsEinheit());
	}

	OrganisationsEinheit updateOrganisationsEinheit(OrganisationsEinheit persistedOrganisationsEinheit,
			OrganisationsEinheit transferredOrganisationsEinheit) {
		transferredOrganisationsEinheit.getZustaendigkeiten().addAll(persistedOrganisationsEinheit.getZustaendigkeiten());
		return transferredOrganisationsEinheit.toBuilder()
				.id(persistedOrganisationsEinheit.getId())
				.vorgangManagerAddress(persistedOrganisationsEinheit.getVorgangManagerAddress())
				.build();
	}
}
