/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import static org.springframework.security.oauth2.client.web.reactive.function.client.ServerOAuth2AuthorizedClientExchangeFilterFunction.*;

import org.springframework.http.HttpStatusCode;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.web.reactive.function.client.WebClient;

import de.ozgcloud.common.errorhandling.TechnicalException;
import lombok.RequiredArgsConstructor;
import reactor.core.publisher.Mono;

@Service
@RequiredArgsConstructor
class PvogRemoteService {

	static final String HTTP_5XX_ERROR = "The remote service responded with an error. Code HTTP ";
	static final String HTTP_4XX_ERROR = "Error using the remote service. Code HTTP ";

	static final String PARAM_INDEX = "index";
	static final String PARAM_ARS = "ars";

	private final WebClient webClient;
	private final PvogProperties properties;

	public AntwortTransfernachricht getVerwaltungsObjekte(int index, String ars) throws TechnicalException {
		return webClient.get()
				.uri(uriBuilder -> uriBuilder
						.path(properties.getEndpoints().verwaltungsobjekte().path())
						.queryParam(PARAM_INDEX, index)
						.queryParam(PARAM_ARS, ars)
						.build())
				.attributes(clientRegistrationId(properties.getRegistrationId()))
				.accept(MediaType.APPLICATION_JSON)
				.retrieve()
				.onStatus(HttpStatusCode::is4xxClientError,
						clientResponse -> Mono.error(new TechnicalException(HTTP_4XX_ERROR + clientResponse.statusCode().value())))
				.onStatus(HttpStatusCode::is5xxServerError,
						clientResponse -> Mono.error(new TechnicalException(HTTP_5XX_ERROR + clientResponse.statusCode().value())))
				.bodyToMono(AntwortTransfernachricht.class)
				.block();
	}
}
