/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import de.ozgcloud.common.errorhandling.ExceptionUtil;
import de.ozgcloud.common.errorhandling.TechnicalException;
import de.ozgcloud.common.logging.OzgCloudLogging;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Service
@OzgCloudLogging
@RequiredArgsConstructor
@Log4j2
class PvogService {

	private final PvogRemoteService remoteService;
	private final ZufiProperties zufiProperties;

	public AntwortTransfernachricht getVerwaltungsObjekteAt(int index) {
		try {
			return remoteService.getVerwaltungsObjekte(index, zufiProperties.getAmtlicheRegionalSchluessel());
		} catch (TechnicalException e) {
			var messageWithExceptionId = ExceptionUtil.formatMessageWithExceptionId(e.getMessage(), e.getExceptionId());
			LOG.error("TechnicalException on Request: {}", messageWithExceptionId);
			throw e;
		}
	}

	public boolean containsVerwaltungsObjekte(AntwortTransfernachricht transfernachricht) {
		return StringUtils.isNotEmpty(transfernachricht.xzufiObjekte());
	}

	public boolean hasMoreData(AntwortTransfernachricht transfernachricht) {
		return !transfernachricht.vollstaendig();
	}
}
