/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import java.util.Objects;

import org.mapstruct.Condition;
import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.ReportingPolicy;
import org.mapstruct.SubclassMapping;

import de.ozgcloud.zufi.schema.Identifikator;
import de.ozgcloud.zufi.schema.LoescheObjekt;
import de.ozgcloud.zufi.schema.SchreibeObjekt;
import de.ozgcloud.zufi.schema.ZustaendigkeitTransferObjekt;

@Mapper(unmappedTargetPolicy = ReportingPolicy.WARN, uses = { OrganisationsEinheitMapper.class, ZustaendigkeitMapper.class })
interface TransferOperationEntryMapper {
	String SCHEME_ID_ZUSTAENDIGKEIT = "ZustaendigkeitOrganisationseinheit";
	String KLASSE_ORGANISATIONSEINHEIT = "Organisationseinheit";

	@SubclassMapping(target = TransferOperationEntry.class, source = SchreibeObjekt.class)
	@SubclassMapping(target = TransferOperationEntry.class, source = LoescheObjekt.class)
	@Mapping(target = "operationType", constant = "UNKNOWN")
	@Mapping(target = "organisationsEinheit", ignore = true)
	@Mapping(target = "zustaendigkeit", ignore = true)
	TransferOperationEntry mapEntry(Object entry);

	@Mapping(target = "organisationsEinheit", source = "organisationseinheit")
	@Mapping(target = "zustaendigkeit", source = "zustaendigkeitTransferObjekt")
	@Mapping(target = "operationType", constant = "WRITE")
	TransferOperationEntry mapSchreibeObjekt(SchreibeObjekt schreibeObjekt);

	@Condition
	default boolean mapsToZustaendigkeitOrganisationsEinheit(ZustaendigkeitTransferObjekt zustaendigkeitTransferObjekt) {
		if (Objects.isNull(zustaendigkeitTransferObjekt) || zustaendigkeitTransferObjekt.getZustaendigkeit().isEmpty()) {
			return false;
		}
		return SCHEME_ID_ZUSTAENDIGKEIT.equals(zustaendigkeitTransferObjekt.getZustaendigkeit().getFirst().getId().getSchemeID());
	}

	@Mapping(target = "operationType", constant = "DELETE")
	@Mapping(target = "organisationsEinheit", conditionExpression = "java(containsOrgansisationseinheit(loescheObjekt))", source = "id")
	@Mapping(target = "zustaendigkeit", conditionExpression = "java(containsZustaendigkeit(loescheObjekt))", source = "id")
	TransferOperationEntry mapLoescheObjekt(LoescheObjekt loescheObjekt);

	default boolean containsZustaendigkeit(LoescheObjekt loescheObjekt) {
		return SCHEME_ID_ZUSTAENDIGKEIT.equals(loescheObjekt.getId().getSchemeID());
	}

	default boolean containsOrgansisationseinheit(LoescheObjekt loescheObjekt) {
		return KLASSE_ORGANISATIONSEINHEIT.equals(loescheObjekt.getKlasse());
	}

	@Mapping(target = "xzufiId.id", source = "value")
	@Mapping(target = "xzufiId.schemeAgencyId", source = "schemeAgencyID")
	@Mapping(target = "gebietId", ignore = true)
	Zustaendigkeit mapZustaendigkeitId(Identifikator id);

	@Mapping(target = "id", ignore = true)
	@Mapping(target = "anschrift", ignore = true)
	@Mapping(target = "name", ignore = true)
	@Mapping(target = "synonyme", ignore = true)
	@Mapping(target = "vorgangManagerAddress", ignore = true)
	@Mapping(target = "zustaendigkeiten", ignore = true)

	@Mapping(target = "xzufiId.id", source = "value")
	@Mapping(target = "xzufiId.schemeAgencyId", source = "schemeAgencyID")
	OrganisationsEinheit mapOrganisationsEinheitId(Identifikator id);
}
