/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi;

import static com.github.tomakehurst.wiremock.core.WireMockConfiguration.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.RegisterExtension;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.SpyBean;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.DynamicPropertyRegistry;
import org.springframework.test.context.DynamicPropertySource;

import com.github.tomakehurst.wiremock.common.ConsoleNotifier;
import com.github.tomakehurst.wiremock.junit5.WireMockExtension;

import de.ozgcloud.common.test.DbInitializer;
import de.ozgcloud.zufi.common.Oauth2Initializer;
import de.ozgcloud.zufi.common.PvogServiceStubSetup;
import de.ozgcloud.zufi.organisationseinheit.PvogProperties.Endpoint;
import de.ozgcloud.zufi.organisationseinheit.PvogProperties.Endpoints;

@SpringBootTest(properties = { "ozgcloud.command.line.runner.enabled=true" })
@ActiveProfiles({ "itcase" })
@ContextConfiguration(initializers = { Oauth2Initializer.class, DbInitializer.class })
class PvogProcessorRunnerITCase {
	private static final String API_SERVER_URL_PROPERTY = "ozgcloud.pvog.url";
	private static final String API_ENDPOINT_PATH_PROPERTY = "ozgcloud.pvog.endpoints.verwaltungsobjekte.path";
	private static final String API_ENDPOINT_PATH = "/api/endpoint";

	@SpyBean
	private PvogProcessorRunner runner;

	@RegisterExtension
	static WireMockExtension wireMock = WireMockExtension.newInstance()
			.options(wireMockConfig().dynamicPort().notifier(new ConsoleNotifier(true)))
			.configureStaticDsl(true)
			.build();

	@BeforeAll
	static void setup() {
		new PvogServiceStubSetup(wireMock.getRuntimeInfo(), new PvogServiceStubSetup.QueryParams("[0-9]+", "01%"),
				new Endpoints(new Endpoint(API_ENDPOINT_PATH))).setupStub();
	}

	@DynamicPropertySource
	static void configureProperties(DynamicPropertyRegistry registry) {
		registry.add(API_SERVER_URL_PROPERTY, wireMock::baseUrl);
		registry.add(API_ENDPOINT_PATH_PROPERTY, () -> API_ENDPOINT_PATH);
	}

	@Test
	void shouldRunPvogProcessRunner() {
		verify(runner).run();
	}
}