/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.common;

import java.time.Duration;

import org.springframework.boot.test.util.TestPropertyValues;
import org.springframework.context.ApplicationContextInitializer;
import org.springframework.context.ConfigurableApplicationContext;
import org.testcontainers.containers.wait.strategy.Wait;

import dasniko.testcontainers.keycloak.KeycloakContainer;
import lombok.extern.log4j.Log4j2;

@Log4j2
public class Oauth2Initializer implements ApplicationContextInitializer<ConfigurableApplicationContext> {

	private static final String AUTH_SERVER_URL = "ozgcloud.pvog.oauth2.auth-server-url";

	private static KeycloakContainer keycloakContainer;

	@Override
	public void initialize(ConfigurableApplicationContext applicationContext) {
		initContainer();
		setProperties(applicationContext);
	}

	@SuppressWarnings("resource")
	private void initContainer() {
		if (keycloakContainer == null) {
			LOG.info("Creating Keycloak-container...");
			keycloakContainer = new KeycloakContainer().withRealmImportFile("keycloak/realm-export.json");
		}
		if (!keycloakContainer.isRunning()) {
			LOG.info("Starting Keycloak-container...");
			keycloakContainer.setWaitStrategy(
					Wait.forLogMessage(".*message\":\"started.*", 1).withStartupTimeout(Duration.ofMinutes(3)));
			keycloakContainer.start();
			LOG.info("Keycloak-container started");
		}
	}

	private void setProperties(ConfigurableApplicationContext applicationContext) {
		LOG.info("Keycloak URL: {}", keycloakContainer.getAuthServerUrl());

		TestPropertyValues.of(AUTH_SERVER_URL + "=" + keycloakContainer.getAuthServerUrl()).applyTo(applicationContext);
	}
}
