/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.common;

import static com.github.tomakehurst.wiremock.client.WireMock.*;
import static de.ozgcloud.zufi.organisationseinheit.AntwortTransfernachrichtTestFactory.*;

import java.net.URLEncoder;
import java.nio.charset.StandardCharsets;

import org.apache.commons.lang3.StringUtils;

import com.github.tomakehurst.wiremock.client.WireMock;
import com.github.tomakehurst.wiremock.junit5.WireMockRuntimeInfo;

import de.ozgcloud.zufi.organisationseinheit.PvogProperties;
import jakarta.ws.rs.core.MediaType;

public class PvogServiceStubSetup {

	private static final String CONTENT_TYPE = "Content-Type";

	private static final String VERWALTUNGSOBJEKTE_ENDPOINT_QUERY_PARAMS = "\\?index=%s&ars=%s";

	private final String verwaltungsobjekteEndpointUrl;

	private final WireMock wireMockServer;

	private final String index;

	private final String encodedArs;

	public PvogServiceStubSetup(WireMockRuntimeInfo wmRuntimeInfo, QueryParams queryParams, PvogProperties.Endpoints endpoints) {
		wireMockServer = wmRuntimeInfo.getWireMock();
		this.index = queryParams.index;
		this.encodedArs = URLEncoder.encode(queryParams.ars, StandardCharsets.UTF_8);
		verwaltungsobjekteEndpointUrl = endpoints.verwaltungsobjekte().path() + VERWALTUNGSOBJEKTE_ENDPOINT_QUERY_PARAMS;
	}

	public void setupStub() {
		definePvogServiceResponse();
		defineErrorPvogServiceResponse();
	}

	private void definePvogServiceResponse() {
		wireMockServer.register(get(urlMatching(String.format(verwaltungsobjekteEndpointUrl, index, encodedArs)))
				.willReturn(aResponse()
						.withHeader(CONTENT_TYPE, MediaType.APPLICATION_JSON)
						.withBody(XZUFI_RESPONSE)));
	}

	private void defineErrorPvogServiceResponse() {
		wireMockServer.register(get(urlMatching(String.format(verwaltungsobjekteEndpointUrl, index, ERROR_ARS)))
				.willReturn(aResponse()
						.withHeader(CONTENT_TYPE, MediaType.APPLICATION_JSON)
						.withStatus(500)
						.withBody(StringUtils.EMPTY)));
	}

	public record QueryParams(String index, String ars) {
	}
}
