/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import de.ozgcloud.zufi.schema.LoescheObjekt;

public class LoescheObjektTestFactory {
	public static final String SCHME_ID_ZUSTAENDIGKEIT = "ZustaendigkeitOrganisationseinheit";
	public static final String KLASSE_ZUSTAENDIGKEIT = "Zustaendigkeit";
	public static final String KLASSE_ORGANISATIONSEINHEIT = "Organisationseinheit";

	public static LoescheObjekt create() {
		return createWithId(IdentifikatorTestFactory.VALUE);
	}

	public static LoescheObjekt createWithId(String id) {
		var loescheObjekt = new LoescheObjekt();
		loescheObjekt.setId(IdentifikatorTestFactory.create(id));

		return loescheObjekt;
	}

	public static LoescheObjekt createForOrganisationseinheit() {
		var loescheObjekt = create();
		loescheObjekt.setKlasse(KLASSE_ORGANISATIONSEINHEIT);
		return loescheObjekt;
	}

	public static LoescheObjekt createForOrganisationseinheitWithID(String id) {
		var loescheObjekt = createWithId(id);
		loescheObjekt.setKlasse(KLASSE_ORGANISATIONSEINHEIT);
		return loescheObjekt;
	}

	public static LoescheObjekt createForZustaendigkeit() {
		var zustaendigkeitId = IdentifikatorTestFactory.create();
		zustaendigkeitId.setSchemeID(SCHME_ID_ZUSTAENDIGKEIT);
		var loescheObjekt = new LoescheObjekt();
		loescheObjekt.setId(zustaendigkeitId);
		loescheObjekt.setKlasse(KLASSE_ZUSTAENDIGKEIT);
		return loescheObjekt;
	}
}
