/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import java.util.HashSet;
import java.util.List;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.zufi.schema.Organisationseinheit;

class OrganisationsEinheitMapperTest {
	@InjectMocks
	private final OrganisationsEinheitMapper mapper = Mappers.getMapper(OrganisationsEinheitMapper.class);
	@Mock
	private XzufiIdMapperImpl xzufiIdMapper;
	@Mock
	private AnschriftMapper anschriftMapper;

	@BeforeEach
	void setUpXZufiMapper() {
		when(xzufiIdMapper.fromIdentifikator(any())).thenCallRealMethod();
	}

	@Nested
	class TestFromXZufiOrganisationseinheit {
		private Organisationseinheit xZufiOrga = ZufiOrganisationsEinheitTestFactory.create();

		@Test
		void shouldMapOrganisationsEinheitId() {
			var organisationsEinheit = callMapper();

			assertThat(organisationsEinheit.getXzufiId().getId()).isEqualTo(IdentifikatorTestFactory.VALUE);
		}

		@Test
		void shouldMapSchemeAgencyID() {
			var organisationsEinheit = callMapper();

			assertThat(organisationsEinheit.getXzufiId().getSchemeAgencyId()).isEqualTo(xZufiOrga.getId().getSchemeAgencyID());
		}

		@Test
		void shouldMapName() {
			var organisationsEinheit = callMapper();

			assertThat(organisationsEinheit.getName()).isEqualTo(NameOrganisationTestFactory.VALUE);
		}

		@Test
		void shouldMapSynonyme() {
			var organisationsEinheit = callMapper();

			assertThat(organisationsEinheit.getSynonyme()).containsIgnoringWhitespaces(ZufiOrganisationsEinheitTestFactory.SYNONYME_1.getValue(),
					ZufiOrganisationsEinheitTestFactory.SYNONYME_2.getValue());
		}

		@Test
		void shouldSetZustaendigkeitenToEmptySet() {
			var organisationsEinheit = callMapper();

			assertThat(organisationsEinheit.getZustaendigkeiten()).isEmpty();
		}

		@Test
		void shouldMapZustaendigkeitenToHashSet() {
			var organisationsEinheit = callMapper();

			assertThat(organisationsEinheit.getZustaendigkeiten()).isInstanceOf(HashSet.class);
		}

		@Test
		void shouldIgnoreId() {
			var organisationsEinheit = callMapper();

			assertThat(organisationsEinheit.getId()).isNull();

		}

		@Test
		void shouldMapAnschrift() {
			var anschrift = AnschriftTestFactory.create();
			when(anschriftMapper.fromXzufiAnschriften(List.of(ZufiOrganisationsEinheitTestFactory.ANSCHRIFT))).thenReturn(anschrift);

			var organisationsEinheit = callMapper();

			assertThat(organisationsEinheit.getAnschrift()).isEqualTo(anschrift);
		}

		private OrganisationsEinheit callMapper() {
			return mapper.fromXZufiOrganisationseinheit(xZufiOrga);
		}
	}
}
