/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.Spy;

import de.ozgcloud.zufi.common.OperationType;

class TransferOperationEntryProcessorTest {

	@Spy
	private TransferOperationEntryProcessor processor;

	@Nested
	class TestProcess {

		@Test
		void shouldCheckIfProcessingRequired() {
			var entry = TransferOperationEntryTestFactory.createWriteEntry();

			processor.process(entry);

			verify(processor).shouldProcess(entry);
		}

		@Nested
		class OnShouldProcess {

			@BeforeEach
			void mockShouldProcess() {
				doReturn(true).when(processor).shouldProcess(any(TransferOperationEntry.class));
			}

			@Test
			void shouldWrite() {
				var entry = TransferOperationEntryTestFactory.createWriteEntry();

				processor.process(entry);

				verify(processor).processWrite(entry);
			}

			@Test
			void shouldDelete() {
				var entry = TransferOperationEntryTestFactory.createDeleteEntry();

				processor.process(entry);

				verify(processor).processDelete(entry);
			}

			@Test
			void shouldNotProcess() {
				var entry = TransferOperationEntryTestFactory.createWriteEntryBuilder()
						.operationType(OperationType.UNKNOWN)
						.build();

				processor.process(entry);

				verify(processor, never()).processWrite(any());
				verify(processor, never()).processDelete(any());
			}
		}

		@Nested
		class OnShouldNotProcess {

			@BeforeEach
			void mockShouldProcess() {
				doReturn(false).when(processor).shouldProcess(any(TransferOperationEntry.class));
			}

			@Test
			void shouldNotProcess() {
				var entry = TransferOperationEntryTestFactory.createWriteEntry();

				processor.process(entry);

				verify(processor, never()).processWrite(any());
				verify(processor, never()).processDelete(any());
			}
		}
	}
}
