/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import de.ozgcloud.zufi.common.OperationType;

public class TransferOperationEntryTestFactory {
	public static final OrganisationsEinheit ORGANISATIONS_EINHEIT = OrganisationsEinheitTestFactory.create();
	public static final Zustaendigkeit ZUSTAENDIGKEIT = ZustaendigkeitTestFactory.create();

	public static TransferOperationEntry createWriteEntry() {
		return createWriteEntryBuilder().build();
	}

	public static TransferOperationEntry createWriteOrganisationsEinheitEntry() {
		return createWriteEntryBuilder()
				.organisationsEinheit(ORGANISATIONS_EINHEIT)
				.build();
	}

	public static TransferOperationEntry createWriteZustaendigkeitEntry() {
		return createWriteEntryBuilder()
				.zustaendigkeit(ZUSTAENDIGKEIT)
				.build();
	}

	public static TransferOperationEntry.TransferOperationEntryBuilder createWriteEntryBuilder() {
		return TransferOperationEntry.builder()
				.operationType(OperationType.WRITE);
	}

	public static TransferOperationEntry createDeleteEntry() {
		return createDeleteEntryBuilder().build();
	}

	public static TransferOperationEntry createDeleteOrganisationsEinheitEntry() {
		return createDeleteEntryBuilder()
				.organisationsEinheit(ORGANISATIONS_EINHEIT)
				.build();
	}

	public static TransferOperationEntry createDeleteZustaendigkeitEntry() {
		return createDeleteEntryBuilder()
				.zustaendigkeit(ZUSTAENDIGKEIT)
				.build();
	}

	public static TransferOperationEntry.TransferOperationEntryBuilder createDeleteEntryBuilder() {
		return TransferOperationEntry.builder()
				.operationType(OperationType.DELETE);
	}

}
