/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;

import de.ozgcloud.common.test.ITCase;
import de.ozgcloud.zufi.common.Oauth2Initializer;
import de.ozgcloud.zufi.common.OperationType;
import de.ozgcloud.zufi.schema.TransferOperation040502;

@ITCase
@ContextConfiguration(initializers = { Oauth2Initializer.class })
class TransferOperationMapperITCase {
	@Autowired
	private TransferOperationMapper mapper;

	@DisplayName("Verify the received transfer object")
	@Nested
	class TestMappedData {
		@Test
		void shouldHaveEntries() {
			var data = map();

			assertThat(data.getEntries()).hasSize(AntwortTransfernachrichtTestFactory.ANZAHL_OBJEKTE);
		}

		@DisplayName("Verify the mapped schreibe data object")
		@Nested
		class VerifySchreibeObjekt {
			@Test
			void shouldHaveOperationWrite() {
				var data = map();

				assertThat(data.getEntries().getFirst().getOperationType()).isEqualTo(OperationType.WRITE);
			}

			@Test
			void shouldHaveOrganisationsEinheit() {
				var data = map();

				assertThat(data.getEntries().getFirst().getOrganisationsEinheit()).isNotNull();
			}

		}

		@DisplayName("Verify the mapped loesche data object")
		@Nested
		class VerifyLoescheObjekt {
			private static final String KIEL_ID = "10324180";

			@Test
			void shouldHaveOperationDelete() {
				var data = map();

				assertThat(data.getEntries().getFirst().getOperationType()).isEqualTo(OperationType.DELETE);
			}

			@Test
			void shouldSetOrganisationsEinheitId() {
				var data = map();

				var organisationsEinheit = data.getEntries().getFirst().getOrganisationsEinheit();
				assertThat(organisationsEinheit.getXzufiId().getId()).isEqualTo(KIEL_ID);
			}

			private TransferOperation map() {
				return mapper.fromXzufi(XzufiTestUtils.unmarshal(createLoescheTransferObject()));
			}

			private String createLoescheTransferObject() {
				var transferOperation = new TransferOperation040502();
				transferOperation.getTransferOperation().add(
						LoescheObjektTestFactory.createForOrganisationseinheitWithID(KIEL_ID));
				return XzufiTestUtils.marshal(transferOperation);
			}
		}
	}

	private TransferOperation map() {
		return mapper.fromXzufi(XzufiTestUtils.unmarshal(AntwortTransfernachrichtTestFactory.XZUFI_OBJEKTE));
	}
}
