/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.zufi.schema.TransferOperation040502;

class TransferOperationMapperTest {

	@Spy
	@InjectMocks
	private final TransferOperationMapper mapper = Mappers.getMapper(TransferOperationMapper.class);
	@Mock
	private TransferOperationEntryMapper entryMapper;
	@Mock
	private XzufiObjekteUnmarshaller xzufiObjekteUnmarshaller;

	@Nested
	class TestFromAntwortTransfernachricht {

		@Mock
		private TransferOperation040502 xzufiTransferOperation;

		@BeforeEach
		void init() {
			when(xzufiObjekteUnmarshaller.unmarshal(AntwortTransfernachrichtTestFactory.XZUFI_OBJEKTE)).thenReturn(xzufiTransferOperation);
			doReturn(TransferOperationTestFactory.create()).when(mapper).fromXzufi(xzufiTransferOperation);
		}

		@Test
		void shouldUnmarshalXzufiObjekte() {
			map();

			verify(xzufiObjekteUnmarshaller).unmarshal(AntwortTransfernachrichtTestFactory.XZUFI_OBJEKTE);
		}

		@Test
		void shouldMapToTransferOperation() {
			map();

			verify(mapper).fromXzufi(xzufiTransferOperation);
		}

		@Test
		void shouldReturnTransferOperation() {
			var transferOperation = map();

			assertThat(transferOperation.getEntries()).isEqualTo(TransferOperationTestFactory.ENTRIES);
		}

		private TransferOperation map() {
			return mapper.fromAntwortTransfernachricht(AntwortTransfernachrichtTestFactory.create());
		}
	}

	@Nested
	class TestFromXzufi {
		@Test
		void shouldCallTransferOperationEntryMapper() {
			map();

			verify(entryMapper, times(AntwortTransfernachrichtTestFactory.ANZAHL_OBJEKTE)).mapEntry(any());
		}

		@Test
		void shouldHaveEntries() {
			var data = map();

			assertThat(data.getEntries()).hasSize(AntwortTransfernachrichtTestFactory.ANZAHL_OBJEKTE);
		}

		private TransferOperation map() {
			return mapper.fromXzufi(XzufiTestUtils.unmarshal(AntwortTransfernachrichtTestFactory.XZUFI_OBJEKTE));
		}
	}
}
