/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.io.InputStream;
import java.nio.charset.StandardCharsets;

import javax.xml.transform.stream.StreamSource;

import org.apache.commons.io.IOUtils;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.ArgumentCaptor;
import org.mockito.Captor;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.springframework.oxm.jaxb.Jaxb2Marshaller;

import de.ozgcloud.zufi.schema.TransferOperation040502;

class XzufiObjekteUnmarshallerTest {

	@Mock
	private Jaxb2Marshaller jaxb2Marshaller;
	@InjectMocks
	private XzufiObjekteUnmarshaller xzufiObjekteUnmarshaller;

	@Nested
	class TestUnmarshal {

		@Mock
		private TransferOperation040502 jaxbTransferOperation;
		@Captor
		private ArgumentCaptor<StreamSource> streamSourceCaptor;

		@BeforeEach
		void init() {
			when(jaxb2Marshaller.unmarshal(any(StreamSource.class))).thenReturn(jaxbTransferOperation);
		}

		@Test
		void shouldUnmarshallPassedString() throws Exception {
			callUnmarshaller();

			verify(jaxb2Marshaller).unmarshal(streamSourceCaptor.capture());
			assertThatIsEqualToExpectedString(streamSourceCaptor.getValue().getInputStream(), AntwortTransfernachrichtTestFactory.XZUFI_OBJEKTE);
		}

		@Test
		void shouldReturnTransferOperation() {
			var result = callUnmarshaller();

			assertThat(result).isEqualTo(jaxbTransferOperation);
		}

		private void assertThatIsEqualToExpectedString(InputStream inputStream, String expectedString) throws Exception {
			String s = new String(IOUtils.toByteArray(inputStream), StandardCharsets.UTF_8);
			assertThat(s).isEqualTo(expectedString);
		}

		private TransferOperation040502 callUnmarshaller() {
			return xzufiObjekteUnmarshaller.unmarshal(AntwortTransfernachrichtTestFactory.XZUFI_OBJEKTE);
		}
	}
}
