/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.NullAndEmptySource;
import org.junit.jupiter.params.provider.ValueSource;

import jakarta.validation.ConstraintViolation;
import jakarta.validation.Validation;
import jakarta.validation.Validator;
import jakarta.validation.ValidatorFactory;

class ZufiPropertiesTest {

	private static ValidatorFactory validatorFactory;
	private static Validator validator;

	@BeforeAll
	static void init() {
		validatorFactory = Validation.buildDefaultValidatorFactory();
		validator = validatorFactory.getValidator();
	}

	@AfterAll
	static void cleanup() {
		validatorFactory.close();
	}

	@Nested
	class TestValidateCode {

		@ParameterizedTest
		@NullAndEmptySource
		void shouldBeNotBlank(String ars) {
			var violations = validator.validate(propertiesWithArs(ars));

			assertThat(violations).hasSize(1).first().extracting(violation -> violation.getPropertyPath().toString(), ConstraintViolation::getMessage)
					.containsExactly("amtlicheRegionalSchluessel", "must not be blank");
		}

		@ParameterizedTest
		@ValueSource(strings = {"01", "01%", "123%"})
		void shouldAcceptArs(String code) {
			var violations = validator.validate(propertiesWithArs(code));

			assertThat(violations).isEmpty();
		}

		private ZufiProperties propertiesWithArs(String ars) {
			var properties = new ZufiProperties();
			properties.setAmtlicheRegionalSchluessel(ars);
			return properties;
		}
	}
}
