/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.zufi.schema.AnschriftOrganisationseinheit;
import de.ozgcloud.zufi.schema.Organisationseinheit;
import de.ozgcloud.zufi.schema.StringLocalized;

public class ZufiOrganisationsEinheitTestFactory {

	public static final AnschriftOrganisationseinheit ANSCHRIFT = AnschriftOrganisationseinheitTestFactory.create();
	public static final StringLocalized SYNONYME_1 = StringLocalizedTestFactory.create(LoremIpsum.getInstance().getWords(5));
	public static final StringLocalized SYNONYME_2 = StringLocalizedTestFactory.create(LoremIpsum.getInstance().getWords(5));

	public static Organisationseinheit create() {
		var organisationsEinheit = createWithoutAnschrift();
		organisationsEinheit.getAnschrift().add(ANSCHRIFT);

		return organisationsEinheit;
	}

	public static Organisationseinheit createWithoutAnschrift() {
		var organisationsEinheit = new Organisationseinheit();
		setBasicProperties(organisationsEinheit);

		return organisationsEinheit;
	}

	private static void setBasicProperties(Organisationseinheit organisationsEinheit) {
		organisationsEinheit.setId(IdentifikatorTestFactory.create());

		organisationsEinheit.getName().add(NameOrganisationTestFactory.create());

		organisationsEinheit.getSynonym().add(SYNONYME_1);
		organisationsEinheit.getSynonym().add(SYNONYME_2);
	}

}