/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.fachstelle;

import java.util.List;

import de.ozgcloud.zufi.grpc.fachstelle.FachstelleServiceGrpc.FachstelleServiceImplBase;
import de.ozgcloud.zufi.grpc.fachstelle.GrpcFachstelleGetRequest;
import de.ozgcloud.zufi.grpc.fachstelle.GrpcFachstelleGetResponse;
import de.ozgcloud.zufi.grpc.fachstelle.GrpcFachstelleSearchRequest;
import de.ozgcloud.zufi.grpc.fachstelle.GrpcFachstelleSearchResponse;
import io.grpc.stub.StreamObserver;
import lombok.RequiredArgsConstructor;
import net.devh.boot.grpc.server.service.GrpcService;

@GrpcService
@RequiredArgsConstructor
class FachstelleGrpcService extends FachstelleServiceImplBase {

	private final FachstelleSearchService searchService;
	private final FachstelleMapper mapper;

	@Override
	public void search(GrpcFachstelleSearchRequest request, StreamObserver<GrpcFachstelleSearchResponse> responseObserver) {
		var fachstellen = searchService.search(request.getSearchBy());
		responseObserver.onNext(buildFachstelleSearchResponse(fachstellen));
		responseObserver.onCompleted();
	}

	GrpcFachstelleSearchResponse buildFachstelleSearchResponse(List<Fachstelle> fachstellen) {
		var responseBuilder = GrpcFachstelleSearchResponse.newBuilder();
		fachstellen.stream().map(mapper::toGrpc).forEach(responseBuilder::addFachstellen);
		return responseBuilder.build();
	}

	public void getById(GrpcFachstelleGetRequest request, StreamObserver<GrpcFachstelleGetResponse> responseObserver) {
		var fachstelle = searchService.getById(request.getId());
		responseObserver.onNext(buildFachstelleGetResponse(fachstelle));
		responseObserver.onCompleted();
	}

	GrpcFachstelleGetResponse buildFachstelleGetResponse(Fachstelle fachstelle) {
		var responseBuilder = GrpcFachstelleGetResponse.newBuilder();
		responseBuilder.setFachstelle(mapper.toGrpc(fachstelle));
		return responseBuilder.build();
	}
}
