/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
class OrganisationsEinheitSearchService {

	private final OrganisationsEinheitRepository repository;

	public OrganisationsEinheit getById(String id) {
		return repository.findById(id).orElseThrow(() -> new OrganisationsEinheitNotFoundException(id));
	}

	public List<OrganisationsEinheit> getByOrganisationsEinheitId(String organisationsEinheitId) {
		return repository.findByOrganisationsEinheitId(organisationsEinheitId);
	}

	public List<OrganisationsEinheit> search(String text, String ars) {
		if (StringUtils.isEmpty(ars)) {
			return repository.findAllContaining(text);
		}
		return repository.findAllContainingInGebiet(text, ars);
	}
}
