/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import java.util.Optional;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import lombok.RequiredArgsConstructor;

@Service
@RequiredArgsConstructor
class VorgangManagerRegistrationService {

	static final String IS_NOT_REGISTERED = StringUtils.EMPTY;

	private final OrganisationsEinheitRepository repository;

	public boolean registerVorgangManager(String vorgangManagerAddress, XzufiId xzufiId) {
		var organisationsEinheit = repository.findFirstByXzufiId(xzufiId);
		return register(organisationsEinheit, vorgangManagerAddress);
	}

	@Deprecated(since = "1.1.0", forRemoval = true)
	public boolean registerVorgangManagerWithOrganisationsEinheit(String vorgangManagerAddress, String organisationsEinheitId) {
		var organisationsEinheit = repository.findFirstByXzufiIdId(organisationsEinheitId);
		return register(organisationsEinheit, vorgangManagerAddress);
	}

	boolean register(Optional<OrganisationsEinheit> optionalOrganisationsEinheit, String vorgangManagerAddress) {
		return optionalOrganisationsEinheit.map(organisationsEinheit -> updateOrganisationsEinheit(organisationsEinheit, vorgangManagerAddress))
				.isPresent();
	}

	OrganisationsEinheit updateOrganisationsEinheit(OrganisationsEinheit organisationsEinheit, String vorgangManagerAddress) {
		return repository.save(setVorgangManagerAddress(organisationsEinheit, vorgangManagerAddress));
	}

	OrganisationsEinheit setVorgangManagerAddress(OrganisationsEinheit organisationsEinheit, String vorgangManagerAddress) {
		return organisationsEinheit.toBuilder()
				.vorgangManagerAddress(vorgangManagerAddress)
				.build();
	}

	public Optional<String> getVorgangManagerAddress(String organisationsEinheitId) {
		return repository.findFirstByXzufiIdId(organisationsEinheitId).map(this::getVorgangManagerAddressOrDefault);
	}

	String getVorgangManagerAddressOrDefault(OrganisationsEinheit organisationsEinheit) {
		return Optional.ofNullable(organisationsEinheit.getVorgangManagerAddress()).orElse(IS_NOT_REGISTERED);
	}

}
