/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.fachstelle;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.util.List;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.boot.test.mock.mockito.MockBean;

import de.ozgcloud.common.test.ITCase;
import de.ozgcloud.zufi.grpc.fachstelle.FachstelleServiceGrpc;
import de.ozgcloud.zufi.grpc.fachstelle.GrpcFachstelle;
import de.ozgcloud.zufi.grpc.fachstelle.GrpcFachstelleSearchRequest;
import net.devh.boot.grpc.client.inject.GrpcClient;

@SpringBootTest(properties = {
		"grpc.server.inProcessName=FachstelleGrpcService-test",
		"grpc.client.inProcess.address=in-process:FachstelleGrpcService-test"
})
@ITCase
class FachstelleGrpcServiceITCase {

	@GrpcClient("inProcess")
	private FachstelleServiceGrpc.FachstelleServiceBlockingStub serviceStub;
	@MockBean
	private FachstelleSearchService searchService;

	@Nested
	class TestSearch {

		private static final String SEARCH_BY = "search phrase";
		private final List<Fachstelle> foundFachstellen = List.of(FachstelleTestFactory.create());
		private final List<GrpcFachstelle> expectedFachstellen = List.of(GrpcFachstelleTestFactory.create());

		@BeforeEach
		void init() {
			when(searchService.search(SEARCH_BY)).thenReturn(foundFachstellen);
		}

		@Test
		void shouldNotThrowException() {
			assertThatNoException().isThrownBy(() -> serviceStub.search(buildRequest()));
		}

		@Test
		void shouldReturnFoundFachstellen() {
			var response = serviceStub.search(buildRequest());

			assertThat(response.getFachstellenList()).containsExactlyElementsOf(expectedFachstellen);
		}

		private GrpcFachstelleSearchRequest buildRequest() {
			return GrpcFachstelleSearchRequest.newBuilder().setSearchBy(SEARCH_BY).build();
		}
	}
}
