/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.fachstelle;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

class FachstelleMapperTest {

	private final FachstelleMapper mapper = Mappers.getMapper(FachstelleMapper.class);

	@Nested
	class TestFromGrpc {

		@Test
		void shouldMapAllSourceFields() {
			var mapped = mapper.fromGrpc(GrpcFachstelleTestFactory.create());

			assertThat(mapped).usingRecursiveComparison().isEqualTo(FachstelleTestFactory.create());
		}
	}

	@Nested
	class TestFromRegistrationGrpc {

		@Test
		void shouldMapAllSourceFields() {
			var mapped = mapper.fromGrpcRegistrationRequest(GrpcFachstelleRegistrationRequestTestFactory.create());

			assertThat(mapped).usingRecursiveComparison().isEqualTo(FachstelleTestFactory.createWithoutId());
		}
	}

	@Nested
	class TestToGrpc {

		@Test
		void shouldSetAllTargetFields() {
			var mapped = mapper.toGrpc(FachstelleTestFactory.create());

			assertThat(mapped).usingRecursiveComparison().isEqualTo(GrpcFachstelleTestFactory.create());
		}

		@Test
		void shouldMapNullValuesToEmptyString() {
			var fachstelleWithNullAnschrift = FachstelleTestFactory.createBuilder().anschrift(null).build();

			var mapped = mapper.toGrpc(fachstelleWithNullAnschrift);

			assertThat(mapped.getAnschrift()).isEmpty();
		}
	}
}
