/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.fachstelle;

import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;
import org.mockito.Spy;

import de.ozgcloud.zufi.grpc.fachstelle.GrpcFachstelleRegistrationRequest;
import de.ozgcloud.zufi.grpc.fachstelle.GrpcFachstelleRegistrationResponse;
import io.grpc.stub.StreamObserver;

class FachstelleRegistrationGrpcServiceTest {

	@Spy
	@InjectMocks
	private FachstelleRegistrationGrpcService grpcService;
	@Mock
	private FachstelleRegistrationService service;
	@Mock
	private FachstelleMapper mapper;

	@Nested
	class TestRegister {

		private final GrpcFachstelleRegistrationRequest registrationRequest = GrpcFachstelleRegistrationRequestTestFactory.create();
		private final Fachstelle fachstelle = FachstelleTestFactory.createWithoutId();
		@Mock
		private StreamObserver<GrpcFachstelleRegistrationResponse> responseObserver;

		@BeforeEach
		void init() {
			when(mapper.fromGrpcRegistrationRequest(registrationRequest)).thenReturn(fachstelle);
			doNothing().when(service).register(fachstelle);
		}

		@Test
		void shouldMapFromGrpc() {
			callService();

			verify(mapper).fromGrpcRegistrationRequest(registrationRequest);
		}

		@Test
		void shouldRegister() {
			callService();

			verify(service).register(fachstelle);
		}

		@Test
		void shouldCallOnNextWithResponse() {
			callService();

			verify(responseObserver).onNext(GrpcFachstelleRegistrationResponse.getDefaultInstance());
		}

		@Test
		void shouldCallOnCompleted() {
			callService();

			verify(responseObserver).onCompleted();
		}

		private void callService() {
			grpcService.register(registrationRequest, responseObserver);
		}
	}
}
