/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.zufi.organisationseinheit;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Mock;

class GrpcOrganisationsEinheitMapperTest {
	@InjectMocks
	private final GrpcOrganisationsEinheitMapper mapper = Mappers.getMapper(GrpcOrganisationsEinheitMapper.class);

	@Mock
	private GrpcAnschriftMapper anschriftMapper;
	@Mock
	private GrpcXzufiIdMapper xzufiIdMapper;

	@Nested
	class TestFromOrganisationsEinheit {

		@BeforeEach
		void mockAnschriftMapper() {
			when(anschriftMapper.fromAnschrift(OrganisationsEinheitTestFactory.ANSCHRIFT)).thenReturn(GrpcAnschriftTestFactory.create());
		}

		@BeforeEach
		void mockXzufiIdMapper() {
			when(xzufiIdMapper.fromXzufiId(OrganisationsEinheitTestFactory.XZUFI_ID)).thenReturn(GrpcXzufiIdTestFactory.create());
		}

		@Test
		void shouldMapOrganisationsEinheit() {
			var organisationsEinheit = mapper.fromOrganisationsEinheit(OrganisationsEinheitTestFactory.create());

			assertThat(organisationsEinheit).usingRecursiveComparison().isEqualTo(GrpcOrganisationsEinheitTestFactory.create());
		}

		@Test
		void shouldHandleMissingSynonyme() {
			var organisationsEinheit = mapper.fromOrganisationsEinheit(OrganisationsEinheitTestFactory.createBuilder().synonyme(null).build());

			assertThat(organisationsEinheit).usingRecursiveComparison()
					.isEqualTo(GrpcOrganisationsEinheitTestFactory.createWithoutSynonyme());
		}
	}
}
